@@ -1146,16 +1146,7 @@ fn transform_jsx_attr_str(v: &str) -> String {
             }
 
             _ => {
-                let escaped = c.escape_unicode().to_string();
-
-                if escaped.starts_with('\\') {
-                    buf.push_str("\\u");
-                    if escaped.len() == 8 {
-                        buf.push_str(&escaped[3..=6]);
-                    } else {
-                        buf.push_str(&escaped[2..]);
-                    }
-                }
+                buf.push(c);
             }
         }
     }
